/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2020 All Rights Reserved.
 */

package com.abssqr.plat.core.service.ast;

import com.abssqr.plat.common.facade.enums.AstPackStatusEnum;
import com.abssqr.plat.common.facade.enums.AstPackTypeEnum;
import com.abssqr.plat.common.facade.enums.CommonTaskTypeEnum;
import com.abssqr.plat.common.facade.param.ast.AstPackOprParam;
import com.abssqr.plat.common.model.convertor.web.AstPackParamConvert;
import com.abssqr.plat.common.model.domain.ast.AstPack;
import com.abssqr.plat.common.model.domain.task.CommonTask;
import com.abssqr.plat.common.model.repo.ast.AstPackRepo;
import com.abssqr.plat.common.model.repo.rule.AstScreenRuleRepo;
import com.abssqr.plat.common.model.repo.task.CommonTaskRepository;
import com.abssqr.plat.core.service.util.CommonTaskUtil;

import com.general.system.common.util.VarChecker;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @author xiachenxiang
 * @version com.abssqr.plat.core.service.ast: AstPackManager.java, v 0.1 2020-04-18 4:16 PM xiachenxiang Exp $
 */
@Component
public class AstPackManager {
    @Autowired
    AstPackRepo          astPackRepository;
    @Autowired
    AstScreenRuleRepo    astScreenRuleRepo;
    @Autowired
    CommonTaskRepository commonTaskRepository;

    /**
     * 新增资产包
     *
     * @param param
     * @return
     */
    public String add(AstPackOprParam param) {
        // 1. 校验重复
        AstPack astPack = astPackRepository.getByAbsPackPackNo(param.getPackNo());
        VarChecker.checkArgument(astPack == null, "资产包已存在{0}", param.getPackNo());
        Long cnt = astPackRepository.cntByPackName(param.getPackName());
        VarChecker.checkEquals(cnt, 0L, "资产包名重复");
        // 2. 保存资产包
        astPack = AstPackParamConvert.param2Model(param);
        astPackRepository.insert(astPack);

        // 3. 保存筛选规则
        astScreenRuleRepo.insertBatch(astPack.getScreenRuleList());

        // 4. 插入资产筛选任务
        CommonTask commonTask = CommonTaskUtil.buildCommonTaskWithContext(param.getPackNo(),CommonTaskTypeEnum.PACK_MATCH,param.getAstPoolNo());
        commonTaskRepository.create(commonTask);
        return param.getPackNo();
    }

    public void craeteDefaultPack(String astPoolNo) {
        AstPack astPack = new AstPack();
        astPack.setAstPoolNo(astPoolNo);
        astPack.setPackNo(astPoolNo);
        astPack.setPackType(AstPackTypeEnum.DEFAULT);
        astPack.setStatus(AstPackStatusEnum.INIT);
        astPackRepository.insert(astPack);
    }
}
